@@ -1,6 +1,8 @@
 from __future__ import annotations
-from parchmint.layer import Layer
+
 from typing import List, Optional, Tuple
+
+from parchmint.layer import Layer
 from parchmint.params import Params
 from parchmint.target import Target
 
@@ -10,7 +12,7 @@ class ConnectionPath:
         self,
         source: Target = None,
         sink: Target = None,
-        waypoints: List[Tuple[int, int]] = [],
+        waypoints: List[Tuple[int, int]] = None,
         json=None,
     ) -> None:
         """Creates a new connection path object
@@ -20,6 +22,8 @@ class ConnectionPath:
             sink (Target): sink corresponding to the path
             waypoints (List[Tuple[int, int]], optional): list of the coordinates. Defaults to [].
         """
+        if waypoints is None:
+            waypoints = []
         super().__init__()
         self.__source: Optional[Target] = source
         self.__sink: Optional[Target] = sink
@@ -30,12 +34,14 @@ class ConnectionPath:
 
     @property
     def source(self) -> Target:
-        assert self.__source is not None
+        if self.__source is None:
+            raise AssertionError
         return self.__source
 
     @property
     def sink(self) -> Target:
-        assert self.__sink is not None
+        if self.__sink is None:
+            raise AssertionError
         return self.__sink
 
     @property
