@@ -8,18 +8,17 @@ class Params:
         Args:
             json (dict, optional): json dict form json.loads(). Defaults to None.
         """
-        self.data = dict()
+        self.data = {}
 
         if json:
             self.parse_from_json(json)
 
-
     def __ne__(self, other) -> bool:
-        """operator overload to compare two params. 
+        """operator overload to compare two params.
         ex. P1 != P2
 
         Args:
-            other (Params): P2 part 
+            other (Params): P2 part
 
         Returns:
             bool: Return true if NOT equal. Otherwise false
@@ -31,7 +30,7 @@ class Params:
             return True
         else:
             for item in self.data:
-                if item not in other.data: 
+                if item not in other.data:
                     return True
                 else:
                     if self.data[item] != other.data[item]:
